==> udata_front-5.2.1.dev29277-py2.py3-none-any.whl: udata_front/theme/gouvfr/datagouv-components/src/types/datasets.ts <==
import type { Badges } from "./badges";
import { Harvest } from "./harvest";
import type { Owned } from "./owned";
import type { Resource } from "./resources";

export type Quality = {
  all_resources_available: boolean;
  dataset_description_quality: boolean;
  has_open_format: boolean;
  has_resources: boolean;
  license: boolean;
  resources_documentation: boolean;
  score: number;
  spatial: boolean;
  temporal_coverage: boolean;
  update_frequency: boolean;
  update_fulfilled_in_time: boolean;
};

export type NewDataset = Owned & {
  title: string;
  acronym: string;
  archived: boolean;
  description: string;
  tags: Array<string> | null;
  license: string;
  frequency: string;
  temporal_coverage: string;
  frequency_date: Date | null;
  page: string;
  private: boolean;
  quality?: Quality;
  spatial: {
    zones?: Array<string>;
    granularity?: string;
  } | null;
};

export type Rel = {
  rel: string;
  href: string;
  total: number;
  type: string;
};

export type Dataset = NewDataset & {
  id: string;
  badges: Badges;
  deleted: string | null;
  page: string;
  resources: Array<Resource>;
  community_resources: Array<Resource>;
  created_at: string;
  last_modified: string;
  last_update: string;
  uri: string;
  slug: string;
  quality: Quality;
  metrics: {
    discussions: number;
    followers: number;
    resources_downloads: number;
    reuses: number;
    views: number;
  };
  harvest: Harvest;
  extras: Record<string, any>;
};

export type DatasetV2 = NewDataset & Omit<Dataset, 'resources' | 'community_resources'> & {
  resources: Rel;
  community_resources: Rel;
};

==> udata_front-5.2.5.dev34400-py2.py3-none-any.whl: udata_front/theme/gouvfr/datagouv-components/src/types/datasets.ts <==
import type { Badges } from "./badges";
import { Harvest } from "./harvest";
import type { Owned, OwnedWithId } from "./owned";
import type { Resource } from "./resources";

export type Quality = {
  all_resources_available: boolean;
  dataset_description_quality: boolean;
  has_open_format: boolean;
  has_resources: boolean;
  license: boolean;
  resources_documentation: boolean;
  score: number;
  spatial: boolean;
  temporal_coverage: boolean;
  update_frequency: boolean;
  update_fulfilled_in_time: boolean;
};

export type BaseDataset = Owned & {
  title: string;
  acronym: string;
  archived: boolean;
  description: string;
  tags: Array<string> | null;
  license: string;
  frequency: string;
  temporal_coverage: string;
  frequency_date: Date | null;
  page: string;
  private: boolean;
  quality?: Quality;
  spatial: {
    zones?: Array<string>;
    granularity?: string;
  } | null;
};

export type NewDataset = Omit<BaseDataset, keyof OwnedWithId> & OwnedWithId;

export type Rel = {
  rel: string;
  href: string;
  total: number;
  type: string;
};

export type Dataset = BaseDataset & {
  id: string;
  badges: Badges;
  deleted: string | null;
  page: string;
  resources: Array<Resource>;
  community_resources: Array<Resource>;
  created_at: string;
  last_modified: string;
  last_update: string;
  uri: string;
  slug: string;
  quality: Quality;
  metrics: {
    discussions: number;
    followers: number;
    resources_downloads: number;
    reuses: number;
    views: number;
  };
  harvest: Harvest;
  extras: Record<string, any>;
};

export type DatasetV2 = Omit<Dataset, 'resources' | 'community_resources'> & {
  resources: Rel;
  community_resources: Rel;
};
